@@ -11,9 +11,6 @@ __doc__ = """\
 1. Linux 要安装 libfuse：  https://github.com/libfuse/libfuse
 2. MacOSX 要安装 MacFUSE： https://github.com/osxfuse/osxfuse
 3. Windows 要安装 WinFsp： https://github.com/winfsp/winfsp
-
-Source Code:  https://github.com/ChenyangGao/web-mount-packs/tree/main/python-cmdline/alist_fuse
-MIT Licensed: https://github.com/ChenyangGao/web-mount-packs/tree/main/python-cmdline/alist_fuse/LICENSE
 """
 
 if __name__ == "__main__":
@@ -33,9 +30,8 @@ else:
 
 
 def main(args):
-    from alist import AlistFileSystem, __version__
-
     if args.version:
+        from alist import __version__
         print(".".join(map(str, __version__)))
         raise SystemExit(0)
 
