@@ -10,5 +10,5 @@ parser = ArgumentParser(
     formatter_class=RawTextHelpFormatter, 
 )
 parser.set_defaults(func=None)
-subparsers = parser.add_subparsers(required=True)
+subparsers = parser.add_subparsers()
 
