@@ -16,7 +16,7 @@ else:
 
 from enum import Enum
 from http.client import HTTPResponse
-from json import dumps, loads
+from json import dumps, load, loads
 from urllib.parse import urlencode
 from urllib.request import urlopen, Request
 
@@ -44,7 +44,7 @@ def get_qrcode_token() -> dict:
     :return: 扫码相关的信息，比如二维码的 uid
     """
     api = "https://qrcodeapi.115.com/api/1.0/web/1.0/token/"
-    return loads(urlopen(api).read())
+    return load(urlopen(api))
 
 
 def get_qrcode_status(payload) -> dict:
@@ -59,7 +59,7 @@ def get_qrcode_status(payload) -> dict:
     :return: 二维码目前的扫码状态信息
     """
     api = "https://qrcodeapi.115.com/get/status/?" + urlencode(payload)
-    return loads(urlopen(api).read())
+    return load(urlopen(api))
 
 
 def post_qrcode_result(uid: str, app: str = "web") -> dict:
@@ -85,7 +85,7 @@ def post_qrcode_result(uid: str, app: str = "web") -> dict:
     app = get_enum_name(app, AppEnum)
     payload = {"app": app, "account": uid}
     api = "https://passportapi.115.com/app/1.0/%s/1.0/login/qrcode/" % app
-    return loads(urlopen(Request(api, data=urlencode(payload).encode("utf-8"), method="POST")).read())
+    return load(urlopen(Request(api, data=urlencode(payload).encode("utf-8"), method="POST")))
 
 
 def get_qrcode(uid: str) -> HTTPResponse:
@@ -180,7 +180,7 @@ def login_with_autoscan(cookie: str, app: str = "web") -> dict:
     token = get_qrcode_token()["data"]
     uid = token["uid"]
     # scanned
-    scanned_data = loads(urlopen(Request(
+    scanned_data = load(urlopen(Request(
         "https://qrcodeapi.115.com/api/2.0/prompt.php?uid=%s" % uid, 
         headers=headers, 
     )))["data"]
@@ -211,13 +211,19 @@ def main(args):
         raise SystemExit(0)
 
     client = AlistClient(args.origin, args.username, args.password)
+    resp = client.admin_user_get(1)
+    if resp["code"] != 200:
+        raise ValueError(resp)
 
-    if args.cookie:
-        resp = login_with_autoscan(args.cookie, args.app)
+    if args.set_cookie:
+        cookie = args.set_cookie
     else:
-        resp = login_with_qrcode(args.app, scan_in_console=not args.open_qrcode)
+        if args.cookie:
+            resp = login_with_autoscan(args.cookie, args.app)
+        else:
+            resp = login_with_qrcode(args.app, scan_in_console=not args.open_qrcode)
+        cookie = "; ".join("%s=%s" % t for t in resp["data"]["cookie"].items())
 
-    cookie = "; ".join("%s=%s" % t for t in resp["data"]["cookie"].items())
     alist_update_115_cookie(client, cookie)
 
 
@@ -226,6 +232,7 @@ parser.add_argument("-o", "--origin", default="http://localhost:5244", help="ali
 parser.add_argument("-u", "--username", default="", help="用户名，默认为空")
 parser.add_argument("-p", "--password", default="", help="密码，默认为空")
 parser.add_argument("-c", "--cookie", help="115 登录 cookie，如果提供了，就可以用这个 cookie 进行自动扫码，否则需要你用手机来手动扫码")
+parser.add_argument("-ck", "--set-cookie", help="115 登录 cookie，如果指定则直接把这个 cookie 更新到 alist")
 parser.add_argument("-op", "--open-qrcode", action="store_true", help="打开二维码图片，而不是在命令行输出")
 parser.add_argument("-v", "--version", action="store_true", help="输出版本号")
 parser.set_defaults(func=main)
