@@ -24,7 +24,6 @@ from requests import Session
 
 from .property import funcproperty
 from .response import get_filename, get_range, get_total_length, is_chunked, is_range_request
-from .urlopen import urlopen
 
 
 _T_co = TypeVar("_T_co", covariant=True)
@@ -112,13 +111,14 @@ def get_filesize(file, /) -> int:
     return total
 
 
+from .urlopen import urlopen
+
 class HTTPFileReader(RawIOBase, BinaryIO):
     url: str | Callable[[], str]
     response: Any
     length: int
     chunked: bool
     start: int
-    closed: bool
     urlopen: Callable
     headers: Mapping
     seek_threshold: int
@@ -205,6 +205,10 @@ class HTTPFileReader(RawIOBase, BinaryIO):
         self.response.close()
         self.__dict__["closed"] = True
 
+    @funcproperty
+    def closed(self, /):
+        return self.__dict__["closed"]
+
     @funcproperty
     def file(self, /) -> BinaryIO:
         return self.response
@@ -300,11 +304,15 @@ class HTTPFileReader(RawIOBase, BinaryIO):
             return start
         self.response.close()
         url = self.url
+        response = self.urlopen(
+            url() if callable(url) else url, 
+            headers={**self.headers, "Range": f"bytes={start}-"}
+        )
+        length_new = get_total_length(response)
+        if self.length != length_new:
+            raise OSError(errno.EIO, f"file size changed: {self.length} -> {length_new}")
         self.__dict__.update(
-            response=self.urlopen(
-                url() if callable(url) else url, 
-                headers={**self.headers, "Range": f"bytes={start}-"}
-            ), 
+            response=response, 
             start=start, 
             closed=False, 
         )
